@@ -19,6 +19,9 @@ from . import progress
 from . import raw
 from . import remote
 
+if sys.version_info[1] < 9:
+    from __future__ import annotations
+
 dirname = pathlib.Path(__file__).resolve().parent
 
 with open(dirname / "undr_schema.json") as undr_schema_file:
