@@ -6,12 +6,16 @@ import html.parser
 import os
 import pathlib
 import re
+import sys
 import threading
 import typing
 from . import certificates
 from . import progress
 from . import utilities
 
+if sys.version_info[1] < 9:
+    from __future__ import annotations
+
 certificates_bundle = certificates.bundle()
 if certificates_bundle is not None:
     os.environ["REQUESTS_CA_BUNDLE"] = certificates_bundle
